<?php


/**
  * SquirrelMail Login Multilogin
  * Copyright (C) 2003, 2004 Paul Lesneiwski <pdontthink@angrynerds.com>
  * This program is licensed under GPL. See COPYING for details
  *
  */


function squirrelmail_plugin_init_multilogin() {

   global $squirrelmail_plugin_hooks;

   $squirrelmail_plugin_hooks['login_form']['multilogin'] = 'multilogin_insertIMAPSelection';
   $squirrelmail_plugin_hooks['login_before']['multilogin'] = 'multilogin_registerIMAPServer';

   // unfortunately, we can only set org_title in the title
   // bar of the browser if we use this hook - otherwise, it's
   // unecessary
   //
   $squirrelmail_plugin_hooks['webmail_top']['multilogin'] = 'multilogin_sqoverride_config';

}



if (!defined('SM_PATH'))
   define('SM_PATH', '../');



function multilogin_version()
{
   return '2.3';
}



/**
  * store the user's IMAP server in the session
  *
  */
function multilogin_registerIMAPServer()
{

   include_once(SM_PATH . 'plugins/multilogin/functions.php');
   multilogin_registerIMAPServer_do();

}


/**
  * present IMAP server selection pull-down
  *
  */
function multilogin_insertIMAPSelection()
{

   include_once(SM_PATH . 'plugins/multilogin/functions.php');
   multilogin_insertIMAPSelection_do();

}



/**
  * present IMAP server selection pull-down
  *
  */
function multilogin_sqoverride_config()
{

   include_once(SM_PATH . 'plugins/multilogin/functions.php');
   multilogin_sqoverride_config_do();

}



?>
